@@ -1,19 +1,20 @@
 package Locale::CLDR::Locales::En::Any;
 
 # This file auto generated
-#	on Sun  3 May  9:56:36 am GMT
+#	on Fri 29 Apr  7:00:04 pm GMT
 
 use version;
 
-our $VERSION = version->declare('v0.27.1');
+our $VERSION = version->declare('v0.29.0');
 
-use v5.10;
+use v5.10.1;
 use mro 'c3';
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose;
+use Moo;
 
 extends('Locale::CLDR::Locales::En');
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
+
+1;
